@@ -36,11 +36,10 @@
 #define HIPCUB_ROCPRIM_BLOCK_BLOCK_RAKING_LAYOUT_HPP_
 
 #include "../../../config.hpp"
+#include "../util_type.hpp"
 
-#include <rocprim/config.hpp>
-#include <rocprim/detail/various.hpp>
-
-#include <type_traits>
+#include <rocprim/config.hpp> // IWYU pragma: export
+#include <rocprim/detail/various.hpp> // IWYU pragma: export
 
 BEGIN_HIPCUB_NAMESPACE
 
